@@ -20,8 +20,8 @@ from pandas import DataFrame
 
 from cloudgeass.aws.s3 import bucket_objects_report
 
-from tests.configs.inputs import MOCKED_BUCKET_NAME,\
-    EXPECTED_DF_OBJECTS_REPORT_COLS
+from tests.configs.inputs import MOCKED_BUCKET_CONTENT,\
+    NON_EMPTY_BUCKETS, EXPECTED_DF_OBJECTS_REPORT_COLS
 
 
 """---------------------------------------------------
@@ -47,15 +47,15 @@ def test_funcao_list_buckets_retorna_o_bucket_esperado(bucket_list):
     """
     G: dado que o usuário deseja obter uma lista de buckets em sua conta
     W: quando o método list_buckets() de cloudgeass.aws.s3 for executado
-       na ciência da existência de um bucket de nome específico
-    T: então a lista resultante deve conter o bucket esperado
+       na ciência da existência de uma lista de buckets definidos
+    T: então a lista resultante deve conter os buckets esperados
     """
-    assert bucket_list[0] == MOCKED_BUCKET_NAME
+    assert bucket_list == list(MOCKED_BUCKET_CONTENT.keys())
 
 
 @pytest.mark.bucket_objects_report
 @mock_s3
-def test_report_de_objetos_do_bucket_gera_dataframe_pandas(
+def test_funcao_bucket_objects_report_gera_dataframe_pandas(
     df_objects_report
 ):
     """
@@ -69,7 +69,7 @@ def test_report_de_objetos_do_bucket_gera_dataframe_pandas(
 
 @pytest.mark.bucket_objects_report
 @mock_s3
-def test_report_de_objetos_do_bucket_possui_atributos_esperados(
+def test_funcao_bucket_objects_report_possui_atributos_esperados(
     df_objects_report
 ):
     """
@@ -84,33 +84,17 @@ def test_report_de_objetos_do_bucket_possui_atributos_esperados(
 
 @pytest.mark.bucket_objects_report
 @mock_s3
-def test_report_de_objetos_do_bucket_possui_apenas_um_nome_de_bucket(
+def test_funcao_bucket_objects_report_possui_apenas_um_nome_de_bucket(
     df_objects_report
 ):
     """
     G: dado que o usuário deseja extrair um report de objetos em um bucket
     W: quando o método bucket_objects_report() for executado com qualquer
        configuração de parâmetros
-    T: então deve haver apenas um valor distinto no atributo "BucketName"
-       do DataFrame resultante
+    T: então deve haver apenas um único valor distinto para o atributo
+       "BucketName" do DataFrame resultante
     """
-    assert len(list(set(df_objects_report["BucketName"].values))) == 1
-
-
-@pytest.mark.bucket_objects_report
-@mock_s3
-def test_report_de_objetos_do_bucket_possui_nome_esperado_de_bucket(
-    df_objects_report
-):
-    """
-    G: dado que o usuário deseja extrair um report de objetos em um bucket
-    W: quando o método bucket_objects_report() for executado com qualquer
-       configuração de parâmetros
-    T: então o valor único distinto do atributo "BucketName" do DataFrame
-       resultante deve ser igual ao nome do bucket alvo da extração
-    """
-    bucket_report_name = list(set(df_objects_report["BucketName"].values))[0]
-    assert bucket_report_name == MOCKED_BUCKET_NAME
+    assert len(set(list(df_objects_report["BucketName"].values))) == 1
 
 
 @pytest.mark.bucket_objects_report
@@ -129,7 +113,7 @@ def test_erro_ao_tentar_gerar_report_de_objetos_com_nome_de_bucket_incorreto(
     prepare_mocked_bucket()
 
     # Modificando nome de bucket para simulação de erro
-    incorrect_bucket_name = MOCKED_BUCKET_NAME + "-error-bucket"
+    incorrect_bucket_name = "cloudgeass-non-existent-bucket"
 
     # Chamando função simulando bucket inexistente na conta
     with pytest.raises(Exception):
@@ -141,7 +125,7 @@ def test_erro_ao_tentar_gerar_report_de_objetos_com_nome_de_bucket_incorreto(
 
 @pytest.mark.all_buckets_objects_report
 @mock_s3
-def test_funcao_bucket_objects_report_retorna_um_dataframe_do_pandas(
+def test_funcao_all_buckets_objects_report_retorna_dataframe_do_pandas(
     df_all_buckets_objects
 ):
     """
@@ -155,7 +139,7 @@ def test_funcao_bucket_objects_report_retorna_um_dataframe_do_pandas(
 
 @pytest.mark.all_buckets_objects_report
 @mock_s3
-def test_funcao_bucket_objects_report_retorna_atributos_esperados(
+def test_funcao_all_buckets_objects_report_retorna_atributos_esperados(
     df_all_buckets_objects
 ):
     """
@@ -165,9 +149,45 @@ def test_funcao_bucket_objects_report_retorna_atributos_esperados(
     T: então um conjunto esperado de atributos deve ser retornado
     """
 
-    # Colunas esperadas do DataFrame
-    expected_cols = ['BucketName', 'Key', 'ObjectType', 'Size',
-                     'SizeFormatted', 'LastModified', 'ETag',
-                     'StorageClass']
+    # Colunas retornadas no DataFrame resultante
+    report_cols = list(df_all_buckets_objects.columns)
 
-    assert list(df_all_buckets_objects.columns) == expected_cols
+    assert report_cols == EXPECTED_DF_OBJECTS_REPORT_COLS
+
+
+@pytest.mark.all_buckets_objects_report
+@mock_s3
+def test_funcao_all_buckets_objects_report_contem_lista_de_buckets_nao_vazios(
+    df_all_buckets_objects
+):
+    """
+    G: dado que o usuário deseja obter um report completo contendo todos
+       os objetos de todos os buckets em sua conta
+    W: quando o método all_buckets_objects_report() for executado
+    T: então deve haver apenas uma lista esperada contendo buckets onde
+       sabe-se previamente que os mesmos estão populados
+    """
+
+    # Extraindo lista de buckets não vazios retornados no DataFrame
+    buckets = list(set(df_all_buckets_objects["BucketName"].values))
+
+    assert len(buckets) == len(NON_EMPTY_BUCKETS)
+
+
+@pytest.mark.all_buckets_objects_report
+@mock_s3
+def test_funcao_all_buckets_objects_report_possui_nomes_esperados_de_buckets(
+    df_objects_report
+):
+    """
+    G: dado que o usuário deseja obter um report completo contendo todos
+       os objetos de todos os buckets em sua conta
+    W: quando o método all_buckets_objects_report() for executado
+    T: então os valores distintos do atributo "BucketName" do DataFrame
+       resultante deve ser igual a lista de buckets não vazios esperada
+    """
+
+    # Extração de nome de bucket do DataFrame resultante
+    bucket_report_names = list(set(df_objects_report["BucketName"].values))
+
+    assert bucket_report_names == NON_EMPTY_BUCKETS
